@@ -125,6 +125,9 @@ INVALIDPARAMETER_KEYWORDERROR = 'InvalidParameter.KeywordError'
 # 多因子Token验证失败。
 INVALIDPARAMETER_MFATOKENERROR = 'InvalidParameter.MFATokenError'
 
+# 名字或者id号错误。
+INVALIDPARAMETER_NAMEORIDCARDERROR = 'InvalidParameter.NameOrIdCardError'
+
 # CAM不支持策略文档中所指定的资源类型。
 INVALIDPARAMETER_NOTSUPPORTPRODUCT = 'InvalidParameter.NotSupportProduct'
 
@@ -227,7 +230,7 @@ INVALIDPARAMETER_SERVICETYPEERROR = 'InvalidParameter.ServiceTypeError'
 # 策略文档的Statement字段不合法。
 INVALIDPARAMETER_STATEMENTERROR = 'InvalidParameter.StatementError'
 
-# 子帐号数量达到上限。
+# 子账号数量达到上限。
 INVALIDPARAMETER_SUBUSERFULL = 'InvalidParameter.SubUserFull'
 
 # 子用户名称重复。
