@@ -205,11 +205,15 @@ class InputCryptoManageMarketingRisk(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _IsAuthorized: 是否授权
+        :param _IsAuthorized: 是否授权：1已授权，否则未授权。
+ 调用全栈式风控引擎接口服务时，客户需先明确授权
+
+
         :type IsAuthorized: str
-        :param _CryptoType: 加密类型
+        :param _CryptoType: 加密类型：1AES加密
+
         :type CryptoType: str
-        :param _CryptoContent: 加密内容
+        :param _CryptoContent: 加密内容，非空时接口采用加密模式。
         :type CryptoContent: str
         """
         self._IsAuthorized = None
@@ -400,7 +404,16 @@ class InputManageMarketingRisk(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _Account: 账号信息。
+        :param _Account: 用户账号类型（默认开通 QQ 开放账号、手机号，手机 MD5 账号类型查询。如需使用微
+信开放账号，则需要 提交工单 由腾讯云进行资格审核，审核通过后方可正常使用微信
+开放账号）： 
+1：QQ 开放账号。 
+2：微信开放账号。 
+4：手机号（暂仅支持国内手机号）。 
+8：设备号（imei/imeiMD5/idfa/idfaMd5）。 
+0： 其他。 
+10004：手机号 MD5。
+
         :type Account: :class:`tencentcloud.rce.v20201103.models.AccountInfo`
         :param _SceneCode: 场景类型：场景SceneCode, 控制台上新建对应的场景并获取对应的值；
 例如：e_register_protection_1521184361
@@ -438,9 +451,12 @@ class InputManageMarketingRisk(AbstractModel):
         :type MacAddress: str
         :param _VendorId: 手机制造商ID，如果手机注册，请带上此信息。
         :type VendorId: str
-        :param _DeviceType: 设备类型：
-1：Android
-2：IOS
+        :param _DeviceType: 设备类型，账号类型为8时必填： 
+0:未知 
+1:Imei;国际移动设备识别号（15-17位数字） 
+2:ImeiMd5；国际移动设备识别号，通过MD5加密后32位的小写字符串 
+3:Idfa; 
+4:IdfaMD5;
         :type DeviceType: int
         :param _Details: 详细信息
         :type Details: list of InputDetails
@@ -448,7 +464,11 @@ class InputManageMarketingRisk(AbstractModel):
         :type Sponsor: :class:`tencentcloud.rce.v20201103.models.SponsorInfo`
         :param _OnlineScam: 可选填写。详情请跳转至OnlineScamInfo查看。
         :type OnlineScam: :class:`tencentcloud.rce.v20201103.models.OnlineScamInfo`
-        :param _Platform: 平台: 1android
+        :param _Platform: 1：安卓
+2：iOS 
+3：H5 
+4：小程序 
+
         :type Platform: str
         """
         self._Account = None
@@ -875,11 +895,22 @@ class OtherAccountInfo(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _AccountId: id
+        :param _AccountId: 其它账号信息：  
+AccountType 是 4 时，填入真实的手机号（如 13123456789）。 
+AccountType 是 8 时，支持 imei、idfa、imeiMD5、idfaMD5入参。  
+AccountType 是 0 时，填入账号信息。  
+AccountType 是 10004 时，填入手机号的 MD5 值。 
+注：imeiMd5 加密方式为：  
+imei 明文小写后，进行 MD5 加密，加密后取小写值。  
+IdfaMd5 加密方式为：idfa 明文大写后，进行 MD5 加密，加密后取小写值。
+
         :type AccountId: str
-        :param _MobilePhone: 手机号
+        :param _MobilePhone: 手机号，若 AccountType 是 4（手机号）、或 10004（手机号 MD5），则无需重复填写 
+否则填入对应的手机号（如 13123456789）。
         :type MobilePhone: str
-        :param _DeviceId: id
+        :param _DeviceId: 用户设备号。若 AccountType 是 8（设备号），则无需重复填写，否则填入对应的设备 
+号。 
+
         :type DeviceId: str
         """
         self._AccountId = None
